/**
 *
 */
package de.intevation.gnv.transition.profile.horizontal;

import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.util.Collection;
import java.util.Iterator;

import org.apache.log4j.Logger;

import au.com.bytecode.opencsv.CSVWriter;

import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.io.ParseException;
import com.vividsolutions.jts.io.WKTReader;

import de.intevation.gnv.chart.ChartLabels;
import de.intevation.gnv.chart.ChartStyle;
import de.intevation.gnv.chart.HorizontalProfileChartFactory;
import de.intevation.gnv.chart.exception.TechnicalChartException;
import de.intevation.gnv.geobackend.base.Result;
import de.intevation.gnv.statistics.HorizontalProfileStatistics;
import de.intevation.gnv.statistics.Statistics;
import de.intevation.gnv.transition.describedata.KeyValueDescibeData;
import de.intevation.gnv.transition.exception.TransitionException;
import de.intevation.gnv.transition.timeseries.TimeSeriesOutputTransition;

import de.intevation.gnv.exports.DefaultExport;
import de.intevation.gnv.exports.ShapeDataCollector;
import de.intevation.gnv.exports.DefaultProfile;
import de.intevation.gnv.exports.Export.Profile;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 * 
 */
public class HorizontalProfileOutputTransition extends
                                              TimeSeriesOutputTransition {
    /**
     * The UID of this class
     */
    private static final long serialVersionUID = 4401516087492028840L;

    private static Logger log = Logger
    .getLogger(HorizontalProfileOutputTransition.class);

    public static final String [] TIMESERIES_CSV_PROFILE_NAMES = {
        "SHAPE",
        "YORDINATE",
        "GROUP1",
        "GROUP2",
        "GROUP3"
    };

    public static final Profile TIMESERIES_CSV_PROFILE =
        new DefaultProfile(
            ',',
            '"',
            '"',
            "CSV",
            "ISO-8859-1");

    /**
     * Constructor
     */
    public HorizontalProfileOutputTransition() {
        super();
        super.domainLable = "Distance [km]";
    }

    /**
     * @see de.intevation.gnv.transition.timeseries.TimeSeriesOutputTransition#createChart(java.io.OutputStream,
     *      java.util.Collection, java.util.Collection, java.lang.String,
     *      de.intevation.gnv.chart.ChartStyle,
     *      de.intevation.gnv.chart.ChartLabels)
     */
    @Override
    protected void createChart(OutputStream outputStream,
                               Collection<KeyValueDescibeData> parameters,
                               Collection<KeyValueDescibeData> measurements,
                               Collection<KeyValueDescibeData> dates,
                               ChartStyle chartStyle, ChartLabels chartLables,
                               String uuid) throws IOException,
                                           TechnicalChartException {
        HorizontalProfileChartFactory chartFactory = new HorizontalProfileChartFactory();
        chartFactory.createProfileChart(chartLables, chartStyle, parameters,
                measurements,dates, outputStream, this.getChartResult(uuid));
    }

    /**
     * @see de.intevation.gnv.transition.timeseries.TimeSeriesOutputTransition#getStatisticsGenerator()
     */
    @Override
    protected Statistics getStatisticsGenerator() {
        return new HorizontalProfileStatistics();
    }

    @Override
    protected void createCSV(OutputStream outputStream,
                             Collection<Result> chartResult)
                                                            throws UnsupportedEncodingException,
                                                            IOException,
                                                            TransitionException {
       
        log.debug("createCSV for HorizontalProfileOutputTransition.");
        DefaultExport export = new DefaultExport(
            new ShapeDataCollector(TIMESERIES_CSV_PROFILE_NAMES));

        export.create(TIMESERIES_CSV_PROFILE, outputStream, chartResult);
    }
}
